Modules
Macros
- define_
graph_ iterator - define_
inst_ type_ enum - impl InstType enum automatically.
- gen_
common_ code - Use this macro to generate some code for instruction to simplify the codesize. Make sure to use this macro in the impl Instruction block and the Instruction struct must have a field named manager which is an instance of InstManager.
- impl_
binary_ inst - impl BinaryInst trait automatically.